package com.mortals.xhx.module.skin.service.impl;

import com.alibaba.fastjson.JSON;
import com.mortals.framework.common.Rest;
import com.mortals.framework.exception.AppException;
import com.mortals.framework.model.Context;
import com.mortals.framework.service.impl.AbstractCRUDServiceImpl;
import com.mortals.xhx.common.code.YesNoEnum;
import com.mortals.xhx.common.pdu.device.DeviceMsgReqPdu;
import com.mortals.xhx.feign.device.IDeviceMessageFeign;
import com.mortals.xhx.module.skin.dao.SkinDao;
import com.mortals.xhx.module.skin.model.SkinEntity;
import com.mortals.xhx.module.skin.service.SkinService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
/**
* SkinService
* 皮肤 service实现
*
* @author zxfei
* @date 2023-04-03
*/
@Service("skinService")
@Slf4j
public class SkinServiceImpl extends AbstractCRUDServiceImpl<SkinDao, SkinEntity, Long> implements SkinService {

    @Autowired
    private IDeviceMessageFeign deviceMessageFeign;


    @Override
    protected void updateBefore(SkinEntity entity, Context context) throws AppException {
        super.updateBefore(entity, context);

        if(YesNoEnum.YES.getValue()==entity.getUsed()){
            //修改非当前皮肤都未未使用
            SkinEntity skinEntity = new SkinEntity();
            skinEntity.setUsed(YesNoEnum.NO.getValue());

            SkinEntity condition = new SkinEntity();
            condition.setUsed(YesNoEnum.YES.getValue());
            this.updateBatch(skinEntity,condition,context);
        }
    }

    @Override
    protected void updateAfter(SkinEntity entity, Context context) throws AppException {
        //推送皮肤更新消息
        DeviceMsgReqPdu deviceMsgReqPdu = new DeviceMsgReqPdu();
        deviceMsgReqPdu.setSiteid(entity.getSiteId());
        deviceMsgReqPdu.setProductCode("tdj");
        deviceMsgReqPdu.setMessageType("edition");
        deviceMsgReqPdu.setData("W10=");
        deviceMsgReqPdu.setTimestamp(System.currentTimeMillis());
        Rest<String> rest = deviceMessageFeign.callbackByProduct(deviceMsgReqPdu);
        log.info("send device message==>{}", JSON.toJSONString(rest));
    }
}